@@ -20,9 +20,8 @@
 relatedInfo <- function(name, message = TRUE){
   name <- stringr::str_to_lower(name)
 
-  req <- httr::GET(paste("https://www.vagalume.com.br/",name,"/index.js"))
-  json <- httr::content(req, encoding = "UTF-8")
-  cont <- jsonlite::fromJSON(json)
+  cont <- paste0("https://www.vagalume.com.br/",name,"/index.js") %>% 
+    jsonlite::fromJSON()
   
   if(!is.null(cont$artist$related)){
     rel <- data.frame(id = cont$artist$id,
