@@ -20,10 +20,8 @@
 #'
 songNames <- function(name, message = TRUE){
   name <- stringr::str_to_lower(name)
-  
-  req <- httr::GET(paste("https://www.vagalume.com.br/",name,"/index.js"))
-  json <- httr::content(req, encoding = "UTF-8")
-  cont <- jsonlite::fromJSON(json)
+  cont <- paste0("https://www.vagalume.com.br/",name,"/index.js") %>% 
+    jsonlite::fromJSON()
 
   if(!is.null(cont)){
     mus <- data.frame(id = cont$artist$id,
