@@ -11,4 +11,7 @@
 #'
 #'   iris %>% as.matrix()
 #'}
-NULL
\ No newline at end of file
+NULL
+
+# Get rid of NOTES
+globalVariables(c(".", "name", "id", "text"))
\ No newline at end of file
